Resource Caching
================

.. currentmodule:: palace

Audio Buffers
-------------

.. autoclass:: Buffer
   :members:

Loading & Freeing in Batch
--------------------------

.. autofunction:: cache

.. autofunction:: free
